# Generated by Django 4.2.23 on 2026-01-26 18:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aatps', '0004_campaignkillmail_final_blow_alliance_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='campaign',
            name='last_run',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
    ]
