# Generated by Django 4.2.23 on 2026-01-24 16:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aatps', '0003_campaignkillmail_ship_group_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='campaignkillmail',
            name='final_blow_alliance_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='campaignkillmail',
            name='final_blow_alliance_name',
            field=models.CharField(blank=True, default='', max_length=255),
        ),
        migrations.AddField(
            model_name='campaignkillmail',
            name='final_blow_char_id',
            field=models.BigIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='campaignkillmail',
            name='final_blow_char_name',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='campaignkillmail',
            name='final_blow_corp_id',
            field=models.BigIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='campaignkillmail',
            name='final_blow_corp_name',
            field=models.CharField(default='', max_length=255),
        ),
    ]
