"""Initialize the app"""
from django.utils.translation import gettext_lazy as _

__version__ = "1.0.5"
__title__ = "TPS"
__title_translated__ = _("AA TPS")

__esi_compatibility_date__ = "2025-11-06"

__package_name__ = "aa-tps"
__app_name__ = "aa-tps"
__app_name_verbose__ = "Alliance Auth Total Participation Statistics"
__app_name_useragent__ = "AA-TPS"

__github_url__ = "https://github.com/BroodLK/aa-tps"
